==> react-conditional-wrap-1.0.3.tgz: package/es/index.js <==
var _excluded = ["when", "thenWrap", "elseWrap", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *                                                                                                 *
 *    hassio-addon-alessio                                                                         *
 *    Copyright (c) 2022 Sgobbi Federico                                                           *
 *    All rights reserved                                                                          *
 *                                                                                                 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
// > > > > > > > > > > > > > > > > > > > > > > > Import externals
import React from 'react'; // > > > > > > > > > > > > > > > > > > > > > > > The code

var defaultWrap = function defaultWrap(_ref) {
  var children = _ref.children;
  return children;
};

var defaultChildren = /*#__PURE__*/React.createElement(React.Fragment, null);

var ConditionalWrap = function ConditionalWrap(_ref2) {
  var _ref2$when = _ref2.when,
      when = _ref2$when === void 0 ? false : _ref2$when,
      _ref2$thenWrap = _ref2.thenWrap,
      thenWrap = _ref2$thenWrap === void 0 ? defaultWrap : _ref2$thenWrap,
      _ref2$elseWrap = _ref2.elseWrap,
      elseWrap = _ref2$elseWrap === void 0 ? defaultWrap : _ref2$elseWrap,
      _ref2$children = _ref2.children,
      children = _ref2$children === void 0 ? defaultChildren : _ref2$children,
      rest = _objectWithoutPropertiesLoose(_ref2, _excluded);

  return /*#__PURE__*/React.createElement(React.Fragment, null, React.Children.map(children, function (child) {
    child = rest ? React.cloneElement(child, rest) : child;

    if (typeof when === 'function' && when(_extends({}, rest, child.props)) || when === true) {
      return thenWrap(_extends({}, rest, child.props, {
        children: child
      }));
    }

    return elseWrap(_extends({}, rest, child.props, {
      children: child
    }));
  }));
}; // > > > > > > > > > > > > > > > > > > > > > > > Module exports


export default ConditionalWrap;

==> react-conditional-wrap-1.0.4.tgz: package/es/index.js <==
var _excluded = ["when", "thenWrap", "elseWrap", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *                                                                                                 *
 *    @digidockage/react-conditional-wrap                                                          *
 *    Copyright (c) 2021 Sgobbi Federico                                                           *
 *    All rights reserved                                                                          *
 *                                                                                                 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
// > > > > > > > > > > > > > > > > > > > > > > > Import externals
import React from 'react'; // > > > > > > > > > > > > > > > > > > > > > > > The code

var defaultWrap = function defaultWrap(_ref) {
  var children = _ref.children;
  return children;
};

var defaultChildren = /*#__PURE__*/React.createElement(React.Fragment, null);

var ConditionalWrap = function ConditionalWrap(_ref2) {
  var _ref2$when = _ref2.when,
      when = _ref2$when === void 0 ? false : _ref2$when,
      _ref2$thenWrap = _ref2.thenWrap,
      thenWrap = _ref2$thenWrap === void 0 ? defaultWrap : _ref2$thenWrap,
      _ref2$elseWrap = _ref2.elseWrap,
      elseWrap = _ref2$elseWrap === void 0 ? defaultWrap : _ref2$elseWrap,
      _ref2$children = _ref2.children,
      children = _ref2$children === void 0 ? defaultChildren : _ref2$children,
      rest = _objectWithoutPropertiesLoose(_ref2, _excluded);

  return /*#__PURE__*/React.createElement(React.Fragment, null, React.Children.map(children, function (child) {
    child = rest ? React.cloneElement(child, rest) : child;

    if (typeof when === 'function' && when(_extends({}, rest, child.props)) || when === true) {
      return thenWrap(_extends({}, rest, child.props, {
        children: child
      }));
    }

    return elseWrap(_extends({}, rest, child.props, {
      children: child
    }));
  }));
}; // > > > > > > > > > > > > > > > > > > > > > > > Module exports


export default ConditionalWrap;
